@@ -176,6 +176,9 @@ fn main() {
                   Some(serde_json::from_str::<uuid::Uuid>(r#"38400000-8cf0-11bd-b23e-10b96e4ef00d"#).expect("Failed to parse JSON example")),
                   None,
                   Some("name_example".to_string()),
+                  Some("location_name_example".to_string()),
+                  Some("location_address_example".to_string()),
+                  Some("location_email_example".to_string()),
                   Some(56),
                   Some(56)
             ));
