@@ -10,7 +10,7 @@ use serde::{Serialize, Deserialize};
 type ServiceError = Box<dyn Error + Send + Sync + 'static>;
 
 pub const BASE_PATH: &'static str = "";
-pub const API_VERSION: &'static str = "0.6.0";
+pub const API_VERSION: &'static str = "0.7.0";
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
@@ -422,6 +422,9 @@ pub trait Api<C: Send + Sync> {
         province_id: Option<uuid::Uuid>,
         province_code: Option<models::Code>,
         name: Option<String>,
+        location_name: Option<String>,
+        location_address: Option<String>,
+        location_email: Option<String>,
         offset: Option<i32>,
         count: Option<i32>,
         context: &C) -> Result<GetDiocesesResponse, ApiError>;
@@ -603,6 +606,9 @@ pub trait ApiNoContext<C: Send + Sync> {
         province_id: Option<uuid::Uuid>,
         province_code: Option<models::Code>,
         name: Option<String>,
+        location_name: Option<String>,
+        location_address: Option<String>,
+        location_email: Option<String>,
         offset: Option<i32>,
         count: Option<i32>,
         ) -> Result<GetDiocesesResponse, ApiError>;
@@ -831,12 +837,15 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
         province_id: Option<uuid::Uuid>,
         province_code: Option<models::Code>,
         name: Option<String>,
+        location_name: Option<String>,
+        location_address: Option<String>,
+        location_email: Option<String>,
         offset: Option<i32>,
         count: Option<i32>,
         ) -> Result<GetDiocesesResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().get_dioceses(province_id, province_code, name, offset, count, &context).await
+        self.api().get_dioceses(province_id, province_code, name, location_name, location_address, location_email, offset, count, &context).await
     }
 
     /// Update an existing diocese
