@@ -242,6 +242,10 @@ pub struct DeaneryCollection {
     #[serde(skip_serializing_if="Option::is_none")]
     pub has_more: Option<bool>,
 
+    #[serde(rename = "total")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub total: Option<i64>,
+
 }
 
 impl DeaneryCollection {
@@ -249,6 +253,7 @@ impl DeaneryCollection {
         DeaneryCollection {
             deaneries: None,
             has_more: None,
+            total: None,
         }
     }
 }
@@ -267,6 +272,12 @@ impl std::string::ToString for DeaneryCollection {
             params.push(has_more.to_string());
         }
 
+
+        if let Some(ref total) = self.total {
+            params.push("total".to_string());
+            params.push(total.to_string());
+        }
+
         params.join(",").to_string()
     }
 }
@@ -283,6 +294,7 @@ impl std::str::FromStr for DeaneryCollection {
         struct IntermediateRep {
             pub deaneries: Vec<Vec<models::Deanery>>,
             pub has_more: Vec<bool>,
+            pub total: Vec<i64>,
         }
 
         let mut intermediate_rep = IntermediateRep::default();
@@ -301,6 +313,7 @@ impl std::str::FromStr for DeaneryCollection {
                 match key {
                     "deaneries" => return std::result::Result::Err("Parsing a container in this style is not supported in DeaneryCollection".to_string()),
                     "hasMore" => intermediate_rep.has_more.push(<bool as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "total" => intermediate_rep.total.push(<i64 as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing DeaneryCollection".to_string())
                 }
             }
@@ -313,6 +326,7 @@ impl std::str::FromStr for DeaneryCollection {
         std::result::Result::Ok(DeaneryCollection {
             deaneries: intermediate_rep.deaneries.into_iter().next(),
             has_more: intermediate_rep.has_more.into_iter().next(),
+            total: intermediate_rep.total.into_iter().next(),
         })
     }
 }
@@ -555,6 +569,10 @@ pub struct DioceseCollection {
     #[serde(skip_serializing_if="Option::is_none")]
     pub has_more: Option<bool>,
 
+    #[serde(rename = "total")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub total: Option<i64>,
+
 }
 
 impl DioceseCollection {
@@ -562,6 +580,7 @@ impl DioceseCollection {
         DioceseCollection {
             dioceses: None,
             has_more: None,
+            total: None,
         }
     }
 }
@@ -580,6 +599,12 @@ impl std::string::ToString for DioceseCollection {
             params.push(has_more.to_string());
         }
 
+
+        if let Some(ref total) = self.total {
+            params.push("total".to_string());
+            params.push(total.to_string());
+        }
+
         params.join(",").to_string()
     }
 }
@@ -596,6 +621,7 @@ impl std::str::FromStr for DioceseCollection {
         struct IntermediateRep {
             pub dioceses: Vec<Vec<models::Diocese>>,
             pub has_more: Vec<bool>,
+            pub total: Vec<i64>,
         }
 
         let mut intermediate_rep = IntermediateRep::default();
@@ -614,6 +640,7 @@ impl std::str::FromStr for DioceseCollection {
                 match key {
                     "dioceses" => return std::result::Result::Err("Parsing a container in this style is not supported in DioceseCollection".to_string()),
                     "hasMore" => intermediate_rep.has_more.push(<bool as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "total" => intermediate_rep.total.push(<i64 as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing DioceseCollection".to_string())
                 }
             }
@@ -626,6 +653,7 @@ impl std::str::FromStr for DioceseCollection {
         std::result::Result::Ok(DioceseCollection {
             dioceses: intermediate_rep.dioceses.into_iter().next(),
             has_more: intermediate_rep.has_more.into_iter().next(),
+            total: intermediate_rep.total.into_iter().next(),
         })
     }
 }
@@ -858,6 +886,10 @@ pub struct InstituteCollection {
     #[serde(skip_serializing_if="Option::is_none")]
     pub has_more: Option<bool>,
 
+    #[serde(rename = "total")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub total: Option<i64>,
+
 }
 
 impl InstituteCollection {
@@ -865,6 +897,7 @@ impl InstituteCollection {
         InstituteCollection {
             institutes: None,
             has_more: None,
+            total: None,
         }
     }
 }
@@ -883,6 +916,12 @@ impl std::string::ToString for InstituteCollection {
             params.push(has_more.to_string());
         }
 
+
+        if let Some(ref total) = self.total {
+            params.push("total".to_string());
+            params.push(total.to_string());
+        }
+
         params.join(",").to_string()
     }
 }
@@ -899,6 +938,7 @@ impl std::str::FromStr for InstituteCollection {
         struct IntermediateRep {
             pub institutes: Vec<Vec<models::Institute>>,
             pub has_more: Vec<bool>,
+            pub total: Vec<i64>,
         }
 
         let mut intermediate_rep = IntermediateRep::default();
@@ -917,6 +957,7 @@ impl std::str::FromStr for InstituteCollection {
                 match key {
                     "institutes" => return std::result::Result::Err("Parsing a container in this style is not supported in InstituteCollection".to_string()),
                     "hasMore" => intermediate_rep.has_more.push(<bool as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "total" => intermediate_rep.total.push(<i64 as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing InstituteCollection".to_string())
                 }
             }
@@ -929,6 +970,7 @@ impl std::str::FromStr for InstituteCollection {
         std::result::Result::Ok(InstituteCollection {
             institutes: intermediate_rep.institutes.into_iter().next(),
             has_more: intermediate_rep.has_more.into_iter().next(),
+            total: intermediate_rep.total.into_iter().next(),
         })
     }
 }
@@ -1170,6 +1212,10 @@ pub struct ParishCollection {
     #[serde(skip_serializing_if="Option::is_none")]
     pub has_more: Option<bool>,
 
+    #[serde(rename = "total")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub total: Option<i64>,
+
 }
 
 impl ParishCollection {
@@ -1177,6 +1223,7 @@ impl ParishCollection {
         ParishCollection {
             parishes: None,
             has_more: None,
+            total: None,
         }
     }
 }
@@ -1195,6 +1242,12 @@ impl std::string::ToString for ParishCollection {
             params.push(has_more.to_string());
         }
 
+
+        if let Some(ref total) = self.total {
+            params.push("total".to_string());
+            params.push(total.to_string());
+        }
+
         params.join(",").to_string()
     }
 }
@@ -1211,6 +1264,7 @@ impl std::str::FromStr for ParishCollection {
         struct IntermediateRep {
             pub parishes: Vec<Vec<models::Parish>>,
             pub has_more: Vec<bool>,
+            pub total: Vec<i64>,
         }
 
         let mut intermediate_rep = IntermediateRep::default();
@@ -1229,6 +1283,7 @@ impl std::str::FromStr for ParishCollection {
                 match key {
                     "parishes" => return std::result::Result::Err("Parsing a container in this style is not supported in ParishCollection".to_string()),
                     "hasMore" => intermediate_rep.has_more.push(<bool as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "total" => intermediate_rep.total.push(<i64 as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing ParishCollection".to_string())
                 }
             }
@@ -1241,6 +1296,7 @@ impl std::str::FromStr for ParishCollection {
         std::result::Result::Ok(ParishCollection {
             parishes: intermediate_rep.parishes.into_iter().next(),
             has_more: intermediate_rep.has_more.into_iter().next(),
+            total: intermediate_rep.total.into_iter().next(),
         })
     }
 }
@@ -1660,6 +1716,10 @@ pub struct ProvinceCollection {
     #[serde(skip_serializing_if="Option::is_none")]
     pub has_more: Option<bool>,
 
+    #[serde(rename = "total")]
+    #[serde(skip_serializing_if="Option::is_none")]
+    pub total: Option<i64>,
+
 }
 
 impl ProvinceCollection {
@@ -1667,6 +1727,7 @@ impl ProvinceCollection {
         ProvinceCollection {
             provinces: None,
             has_more: None,
+            total: None,
         }
     }
 }
@@ -1685,6 +1746,12 @@ impl std::string::ToString for ProvinceCollection {
             params.push(has_more.to_string());
         }
 
+
+        if let Some(ref total) = self.total {
+            params.push("total".to_string());
+            params.push(total.to_string());
+        }
+
         params.join(",").to_string()
     }
 }
@@ -1701,6 +1768,7 @@ impl std::str::FromStr for ProvinceCollection {
         struct IntermediateRep {
             pub provinces: Vec<Vec<models::Province>>,
             pub has_more: Vec<bool>,
+            pub total: Vec<i64>,
         }
 
         let mut intermediate_rep = IntermediateRep::default();
@@ -1719,6 +1787,7 @@ impl std::str::FromStr for ProvinceCollection {
                 match key {
                     "provinces" => return std::result::Result::Err("Parsing a container in this style is not supported in ProvinceCollection".to_string()),
                     "hasMore" => intermediate_rep.has_more.push(<bool as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
+                    "total" => intermediate_rep.total.push(<i64 as std::str::FromStr>::from_str(val).map_err(|x| format!("{}", x))?),
                     _ => return std::result::Result::Err("Unexpected key while parsing ProvinceCollection".to_string())
                 }
             }
@@ -1731,6 +1800,7 @@ impl std::str::FromStr for ProvinceCollection {
         std::result::Result::Ok(ProvinceCollection {
             provinces: intermediate_rep.provinces.into_iter().next(),
             has_more: intermediate_rep.has_more.into_iter().next(),
+            total: intermediate_rep.total.into_iter().next(),
         })
     }
 }
